endpoints

package
v0.0.0-...-8eea3e4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 8, 2025 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var NopAccount = &oc.Account{
	Id:         "",
	SubAccount: false,
	MultiSecret: oc.MultiSecret{
		ApiKeyRef:     secret.Secret("raw:AAA"),
		SecretKeyRef:  secret.Secret("raw:AAA"),
		PassphraseRef: secret.Secret("raw:AAA"),
	},
}

NopAccount is a placeholder account with dummy credentials

Functions

func AccountTransfer

func AccountTransfer(c *fiber.Ctx) error

AccountTransfer handles transfers between accounts on an exchange

func CreateWithdrawal

func CreateWithdrawal(c *fiber.Ctx) error

CreateWithdrawal handles withdrawal requests from an exchange

func GetAccountTypes

func GetAccountTypes(c *fiber.Ctx) error

GetAccountTypes returns the list of valid account types for an exchange

func GetAssets

func GetAssets(c *fiber.Ctx) error

GetAssets returns the list of assets for a specified exchange

func GetBalances

func GetBalances(c *fiber.Ctx) error

GetBalances returns the balances for a specified account

func GetDepositAddress

func GetDepositAddress(c *fiber.Ctx) error

GetDepositAddress returns a deposit address for a specified symbol and network

func ListSubaccounts

func ListSubaccounts(c *fiber.Ctx) error

ListSubaccounts returns the list of configured subaccounts on an exchange

func ListWithdrawalHistory

func ListWithdrawalHistory(c *fiber.Ctx) error

ListWithdrawalHistory returns the withdrawal history for an exchange account

func UnwrapConfig

func UnwrapConfig(c *fiber.Ctx) *oc.Config

func WrapConfig

func WrapConfig(c *fiber.Ctx, conf *oc.Config)

Types

This section is empty.

Jump to