Documentation
¶
Index ¶
- Variables
- func AccountTransfer(c *fiber.Ctx) error
- func CreateWithdrawal(c *fiber.Ctx) error
- func GetAccountTypes(c *fiber.Ctx) error
- func GetAssets(c *fiber.Ctx) error
- func GetBalances(c *fiber.Ctx) error
- func GetDepositAddress(c *fiber.Ctx) error
- func ListSubaccounts(c *fiber.Ctx) error
- func ListWithdrawalHistory(c *fiber.Ctx) error
- func UnwrapConfig(c *fiber.Ctx) *oc.Config
- func WrapConfig(c *fiber.Ctx, conf *oc.Config)
Constants ¶
This section is empty.
Variables ¶
var NopAccount = &oc.Account{ Id: "", SubAccount: false, MultiSecret: oc.MultiSecret{ ApiKeyRef: secret.Secret("raw:AAA"), SecretKeyRef: secret.Secret("raw:AAA"), PassphraseRef: secret.Secret("raw:AAA"), }, }
NopAccount is a placeholder account with dummy credentials
Functions ¶
func AccountTransfer ¶
AccountTransfer handles transfers between accounts on an exchange
func CreateWithdrawal ¶
CreateWithdrawal handles withdrawal requests from an exchange
func GetAccountTypes ¶
GetAccountTypes returns the list of valid account types for an exchange
func GetBalances ¶
GetBalances returns the balances for a specified account
func GetDepositAddress ¶
GetDepositAddress returns a deposit address for a specified symbol and network
func ListSubaccounts ¶
ListSubaccounts returns the list of configured subaccounts on an exchange
func ListWithdrawalHistory ¶
ListWithdrawalHistory returns the withdrawal history for an exchange account
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.